@@ -7,7 +7,7 @@ from pathlib import Path
 from typing import List, Union, Optional
 
 from taskipy.pyproject import PyProject
-from taskipy.exceptions import TaskNotFoundError
+from taskipy.exceptions import TaskNotFoundError, MalformedTaskError
 from taskipy.task import Task
 from taskipy.help import HelpFormatter
 
@@ -36,26 +36,33 @@ class TaskRunner:
 
         pre_task = self.__pre_task(task_name)
         if pre_task is not None:
-            exit_code = self.__run_command_and_return_exit_code(pre_task.command)
+            exit_code = self.__run_command_and_return_exit_code(pre_task)
             if exit_code != 0:
                 return exit_code
 
-        exit_code = self.__run_command_and_return_exit_code(task.command, args)
+        exit_code = self.__run_command_and_return_exit_code(task, args)
         if exit_code != 0:
             return exit_code
 
         post_task = self.__post_task(task_name)
         if post_task is not None:
-            exit_code = self.__run_command_and_return_exit_code(post_task.command)
+            exit_code = self.__run_command_and_return_exit_code(post_task)
             if exit_code != 0:
                 return exit_code
 
         return 0
 
-    def __run_command_and_return_exit_code(self, command: str, args: List[str] = None) -> int:
+    def __run_command_and_return_exit_code(self, task: Task, args: List[str] = None) -> int:
         if args is None:
             args = []
 
+        command = task.command
+        if task.use_vars or self.__project.settings.get('use_vars', {}):
+            try:
+                command = command.format(**self.__project.variables)
+            except KeyError as e:
+                raise MalformedTaskError(task.name, f"{e} variable expected in [pyproject.taskipy.variables]")
+
         if self.__project.runner is not None:
             command = f'{self.__project.runner} {command}'
 
